==> RSTouchscreenNG-1.4.11.zip: RSTouchscreenNG/projects/pages/src/lib/languages.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, ChangeDetectionStrategy} from "@angular/core";
import {getState, Language, RepetierState, ServerAction, VisualAids} from "binding";
import {Observable} from "rxjs";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
    selector: "rs-languages",
    template: `
<rs-page>
<rs-side>
    <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
</rs-side>
<rs-side>
  <rs-sideicon icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-sideicon>
</rs-side>
<rs-side>
  <rs-empty-sideicon></rs-empty-sideicon>
</rs-side>
<main>
    <h1><i class="fa fa-language"></i> <?php _('Language') ?></h1>
    <div class="content-h1" rsDrag>
        <div class="iconlist">
           <div class="button-icon sep-icon-always full" *ngFor="let l of languages$ | async">
                <rs-button class="secondary outline full leftalign" (hit)="selectLanguage(l)">
                    <i *ngIf="(front$ | async).frontSetting"><rs-radio [onValue]="l.id" [value]="(front$ | async).frontSetting.language" class="primary"></rs-radio></i>
                    <h3 class="text single"><img [src]="l.flag"> {{l.name}} {{(front$ | async).language}}</h3>
                </rs-button>
           </div>
        </div>
    </div>
</main>
</rs-page>
`,
    changeDetection: ChangeDetectionStrategy.OnPush
})
export class LanguagesComponent {
    languages$: Observable<Language[]>;
    front$: Observable<any>;

    constructor(private serverAction: ServerAction,
                private visualAid: VisualAids,
                private store: Store<RepetierState>) {
      this.languages$ = store.select((state) => state.server.languages);
      this.front$ = store.select(state => state.server.settings);
    }

    selectLanguage(l: Language) {
        this.serverAction.updateSetting("frontSetting", Object.assign({}, getState(this.store).server.settings["frontSetting"], {language: l.id})).then(() => {
            this.visualAid.showBusy("<?php _('Switching language ...') ?>");
            window.location.assign(window.location.pathname + "?rand=" + Math.random());
        });
    }

}

==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/pages/src/lib/languages.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, ChangeDetectionStrategy} from "@angular/core";
import {getState, Language, RepetierState, ServerAction, VisualAids} from "binding";
import {Observable} from "rxjs";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
    selector: "rs-languages",
    template: `
      <rs-page>
        <rs-side>
          <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
        </rs-side>
        <rs-side>
          <rs-sideicon icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-sideicon>
        </rs-side>
        <rs-side>
          <rs-empty-sideicon></rs-empty-sideicon>
        </rs-side>
        <main>
          <rs-headline><i class="fa fa-language"></i> <?php _('Language') ?></rs-headline>
          <div class="content-h1" rsDrag>
            <div>
              <div class="iconlist margin-leftright">
                <div class="button-icon sep-icon-always full" *ngFor="let l of languages$ | async">
                  <rs-button class="secondary outline full leftalign" (hit)="selectLanguage(l)">
                    <i *ngIf="(front$ | async).frontSetting">
                      <rs-radio [onValue]="l.id" [value]="(front$ | async).frontSetting.language" class="primary"></rs-radio>
                    </i>
                    <h3 class="text single"><img [src]="l.flag"> {{ l.name }} {{ (front$ | async).language }}</h3>
                  </rs-button>
                </div>
              </div>
            </div>
          </div>
        </main>
      </rs-page>
    `,
    changeDetection: ChangeDetectionStrategy.Default})
export class LanguagesComponent {
    languages$: Observable<Language[]>;
    front$: Observable<any>;

    constructor(private serverAction: ServerAction,
                private visualAid: VisualAids,
                private store: Store<RepetierState>) {
      this.languages$ = store.select((state) => state.server.languages);
      this.front$ = store.select(state => state.server.settings);
    }

    selectLanguage(l: Language) {
        this.serverAction.updateSetting("frontSetting", Object.assign({}, getState(this.store).server.settings["frontSetting"], {language: l.id})).then(() => {
            this.visualAid.showBusy("<?php _('Switching language ...') ?>");
            window.location.assign(window.location.pathname + "?rand=" + Math.random());
        });
    }

}
